@@ -1,7 +1,7 @@
 package App::depak;
 
-our $DATE = '2015-11-07'; # DATE
-our $VERSION = '0.50'; # VERSION
+our $DATE = '2016-02-14'; # DATE
+our $VERSION = '0.51'; # VERSION
 
 use 5.010001;
 use strict;
@@ -77,13 +77,15 @@ sub _build_lib {
             my @mods = ($prereq);
             # find prereq's dependencies
             my $res = call_lcpan_script(argv=>["deps", "-R", "--perl-version", $self->{perl_version}->numify, $prereq]);
-            for my $entry (@{ $res }) {
+            die "Can't lcpan deps: $res->[0] - $res->[1]" unless $res->[0] == 200;
+            for my $entry (@{ $res->[2] }) {
                 $entry->{module} =~ s/^\s+//;
                 push @mods, $entry->{module};
             }
             # pull all the other modules from the same dists
             $res = call_lcpan_script(argv=>["mods-from-same-dist", "--latest", "--detail", @mods]);
-            for my $entry (@{ $res }) {
+            die "Can't lcpan mods-from-same-dist: $res->[0] - $res->[1]" unless $res->[0] == 200;
+            for my $entry (@{ $res->[2] }) {
                 $log->debugf("  Adding module: %s (include_prereq %s, dist %s)", $entry->{name}, $prereq, $entry->{dist});
                 $mod_paths{$entry->{name}} = undef;
             }
@@ -161,13 +163,15 @@ sub _build_lib {
                     my @mods = ($prereq);
                     # find prereq's dependencies
                     my $res = call_lcpan_script(argv=>["deps", "-R", "--perl-version", $self->{perl_version}->numify, $prereq]);
-                    for my $entry (@{ $res }) {
+                    die "Can't lcpan deps: $res->[0] - $res->[1]" unless $res->[0] == 200;
+                    for my $entry (@{ $res->[2] }) {
                         $entry->{module} =~ s/^\s+//;
                         push @mods, $entry->{module};
                     }
                     # pull all the other modules from the same dists
                     $res = call_lcpan_script(argv=>["mods-from-same-dist", "--latest", "--detail", @mods]);
-                    for my $entry (@{ $res }) {
+                    die "Can't lcpan mods-from-same-dist: $res->[0] - $res->[1]" unless $res->[0] == 200;
+                    for my $entry (@{ $res->[2] }) {
                         $excluded_prereqs->{$entry->{name}} = $prereq;
                     }
                 }
@@ -960,7 +964,7 @@ App::depak - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.50 of App::depak (from Perl distribution App-depak), released on 2015-11-07.
+This document describes version 0.51 of App::depak (from Perl distribution App-depak), released on 2016-02-14.
 
 =head1 SYNOPSIS
 
@@ -1237,7 +1241,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
